.. _pred_package_matrix_factorization:

Matrix Factorization-based algorithms
-------------------------------------

.. autoclass:: surprise.prediction_algorithms.matrix_factorization.SVD
    :show-inheritance:

.. autoclass:: surprise.prediction_algorithms.matrix_factorization.SVDpp
    :show-inheritance:

.. autoclass:: surprise.prediction_algorithms.matrix_factorization.NMF
    :show-inheritance:
